@@ -16,9 +16,10 @@
 
 #include "buffer.h"
 
-#define  BUFFER_MAX_CHUNK  0x1400000
-#define  BUFFER_MAX_LEN    0x1400000
-#define  BUFFER_ALLOCSZ    0x002000
+#define  BUFFER_MAX_CHUNK       0x1400000
+#define  BUFFER_MAX_LEN         0x1400000
+#define  BUFFER_ALLOCSZ         0x002000
+#define  BUFFER_COMPACT_PERCENT 0.8
 
 #define UnsignedToFloat(u) (((double)((long)(u - 2147483647L - 1))) + 2147483648.0)
 
@@ -98,10 +99,10 @@ static int
 buffer_compact(Buffer *buffer)
 {
   /*
-   * If the buffer is quite empty, but all data is at the end, move the
+   * If the buffer is at least BUFFER_COMPACT_PERCENT empty, move the
    * data to the beginning.
    */
-  if (buffer->offset > MIN(buffer->alloc, BUFFER_MAX_CHUNK)) {
+  if (buffer->offset * 1.0 / buffer->alloc >= BUFFER_COMPACT_PERCENT ) {
 #ifdef AUDIO_SCAN_DEBUG
     PerlIO_printf(PerlIO_stderr(), "Buffer compacting (%d -> %d)\n", buffer->offset + buffer_len(buffer), buffer_len(buffer));
 #endif
@@ -791,7 +792,8 @@ buffer_get_utf16_as_utf8(Buffer *buffer, Buffer *utf8, uint32_t len, uint8_t byt
   
   return i;
 }
-      
+
+#ifdef HAS_GUID
 void
 buffer_get_guid(Buffer *buffer, GUID *g)
 {
@@ -801,6 +803,7 @@ buffer_get_guid(Buffer *buffer, GUID *g)
   
   buffer_get(buffer, g->Data4, 8);
 }
+#endif
 
 int
 buffer_get_float32_le_ret(float *ret, Buffer *buffer)
@@ -959,6 +962,15 @@ buffer_get_ieee_float(Buffer *buffer)
     return f;
 }
 
+void
+put_u16(void *vp, uint16_t v)
+{
+  u_char *p = (u_char *)vp;
+  
+	p[0] = (u_char)(v >> 8) & 0xff;
+	p[1] = (u_char)v & 0xff;
+}
+
 void
 put_u32(void *vp, uint32_t v)
 {
